length property
int
get
length
Returns the total number of pages in the sequence.
Implementation
int get length => pages.length;
Returns the total number of pages in the sequence.
int get length => pages.length;